Python: module cllist

cllist (version 1.0.0) | index /home/media/projects/python-llist/myenv2/lib/python2.7/site-packages/cllist.so

`C-extension providing single and double linked lists.`

Classes
`` |  | __builtin__.object llist.dllist llist.dllistiterator llist.dllistnode llist.sllist llist.sllistiterator llist.sllistnode
class dllist(__builtin__.object)
`` | `Doubly linked list`
| Methods defined here: __add__(...) `x.__add__(y) <==> x+y` __contains__(...) `x.__contains__(y) <==> y in x` __delitem__(...) `x.__delitem__(y) <==> del x[y]` __eq__(...) `x.__eq__(y) <==> x==y` __ge__(...) `x.__ge__(y) <==> x>=y` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __gt__(...) `x.__gt__(y) <==> x>y` __iadd__(...) `x.__iadd__(y) <==> x+=y` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __iter__(...) `x.__iter__() <==> iter(x)` __le__(...) `x.__le__(y) <==> x<=y` __len__(...) `x.__len__() <==> len(x)` __lt__(...) `x.__lt__(y) <==> x<y` __mul__(...) `x.__mul__(n) <==> x*n` __ne__(...) `x.__ne__(y) <==> x!=y` __repr__(...) `x.__repr__() <==> repr(x)` __rmul__(...) `x.__rmul__(n) <==> n*x` __setitem__(...) `x.__setitem__(i, y) <==> x[i]=y` __str__(...) `x.__str__() <==> str(x)` append(...) `Append element at the end of the list` appendleft(...) `Append element at the beginning of the list` appendright(...) `Append element at the end of the list` clear(...) `Remove all elements from the list` extend(...) `Append elements from iterable at the right side of the list` extendleft(...) `Append elements from iterable at the left side of the list` extendright(...) `Append elements from iterable at the right side of the list` index(...) `Returns the first index of a value` insert(...) `Inserts element before node` nodeat(...) `Return node at index` pop(...) `Remove an element by index from the list and return it, or last item if no index provided` popleft(...) `Remove first element from the list and return it` popright(...) `Remove last element from the list and return it` remove(...) `Remove element from the list` rindex(...) `Returns the last index of a value` rotate(...) `Rotate the list n steps to the right` Data descriptors defined here: first `First node` last `Next node` middle `Middle node` size `Number of elements in the list` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class dllistiterator(__builtin__.object)
`` | `Doubly linked list iterator`
| Methods defined here: next(...) `x.next() -> the next value, or raise StopIteration` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class dllistnode(__builtin__.object)
`` | `Doubly linked list node`
| Methods defined here: __call__(...) `x.__call__(...) <==> x(...)` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __repr__(...) `x.__repr__() <==> repr(x)` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: next `Next node` prev `Previous node` value `Value stored in node` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class sllist(__builtin__.object)
`` | `Singly linked list`
| Methods defined here: __add__(...) `x.__add__(y) <==> x+y` __contains__(...) `x.__contains__(y) <==> y in x` __delitem__(...) `x.__delitem__(y) <==> del x[y]` __eq__(...) `x.__eq__(y) <==> x==y` __ge__(...) `x.__ge__(y) <==> x>=y` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __gt__(...) `x.__gt__(y) <==> x>y` __iadd__(...) `x.__iadd__(y) <==> x+=y` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __iter__(...) `x.__iter__() <==> iter(x)` __le__(...) `x.__le__(y) <==> x<=y` __len__(...) `x.__len__() <==> len(x)` __lt__(...) `x.__lt__(y) <==> x<y` __mul__(...) `x.__mul__(n) <==> x*n` __ne__(...) `x.__ne__(y) <==> x!=y` __repr__(...) `x.__repr__() <==> repr(x)` __rmul__(...) `x.__rmul__(n) <==> n*x` __setitem__(...) `x.__setitem__(i, y) <==> x[i]=y` __str__(...) `x.__str__() <==> str(x)` append(...) `Append element at the end of the list` appendleft(...) `Append element at the beginning of the list` appendright(...) `Append element at the end of the list` clear(...) `Remove all elements from the list` extend(...) `Append elements from iterable at the right side of the list` extendleft(...) `Append elements from iterable at the left side of the list` extendright(...) `Append elements from iterable at the right side of the list` index(...) `Returns the first index of a value` insertafter(...) `Inserts element after node` insertbefore(...) `Inserts element before node` nodeat(...) `Return node at index` pop(...) `Remove an element by index from the list and return it, or last item if no index provided` popleft(...) `Remove first element from the list and return it` popright(...) `Remove last element from the list and return it` remove(...) `Remove element from the list` rindex(...) `Returns the last index of a value` rotate(...) `Rotate the list n steps to the right` Data descriptors defined here: first `First node` last `Next node` size `size` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class sllistiterator(__builtin__.object)
`` | `Singly linked list iterator`
| Methods defined here: next(...) `x.next() -> the next value, or raise StopIteration` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`
class sllistnode(__builtin__.object)
`` | `Singly linked list node`
| Methods defined here: __call__(...) `x.__call__(...) <==> x(...)` __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` __repr__(...) `x.__repr__() <==> repr(x)` __str__(...) `x.__str__() <==> str(x)` Data descriptors defined here: next `next node` value `value` Data and other attributes defined here: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T`

Data
`` |  | __version__ = '1.0.0' __version_tuple__ = (1L, 0L, 0L)